@@ -20,11 +20,14 @@
  *
  */
 
+const Gdk = imports.gi.Gdk;
+const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const Soup = imports.gi.Soup;
 const Tp = imports.gi.TelepathyGLib;
 
+const AppNotifications = imports.appNotifications;
 const Signals = imports.signals;
 
 const GPASTE_BASEURL = 'https://paste.gnome.org/'
@@ -33,12 +36,13 @@ const GPASTE_BASEURL = 'https://paste.gnome.org/'
 const _balancedParens = '\\((?:[^\\s()<>]+|(?:\\(?:[^\\s()<>]+\\)))*\\)';
 const _leadingJunk = '[\\s`(\\[{\'\\"<\u00AB\u201C\u2018]';
 const _notTrailingJunk = '[^\\s`!()\\[\\]{};:\'\\".,<>?\u00AB\u00BB\u201C\u201D\u2018\u2019]';
+const _uriList = getURISchemes();
 
 const _urlRegexp = new RegExp(
     '(^|' + _leadingJunk + ')' +
     '(' +
         '(?:' +
-            '(?:http|https|ftp)://' +             // scheme://
+            '(?:' + _uriList.join('|') + '):' +   // scheme:
             '|' +
             'www\\d{0,3}[.]' +                    // www.
             '|' +
@@ -73,6 +77,24 @@ function debug(str) {
         log('DEBUG: ' + str);
 }
 
+function getURISchemes() {
+    let apps = Gio.AppInfo.get_all();
+    let prefix = 'x-scheme-handler/';
+    let schemes = [];
+
+    apps.forEach(function(app) {
+        let types = app.get_supported_types();
+        if (!types)
+            return;
+
+        types.forEach(function(type) {
+            if (type.startsWith(prefix))
+                schemes.push(type.replace(prefix, ''));
+        });
+    });
+    return schemes;
+}
+
 function addJSSignalMethods(proto) {
     proto.connectJS = Signals._connect;
     proto.disconnectJS = Signals._disconnect;
@@ -102,6 +124,19 @@ function findUrls(str) {
     return res;
 }
 
+function openURL(url, timestamp) {
+    let ctx = Gdk.Display.get_default().get_app_launch_context();
+    ctx.set_timestamp(timestamp);
+    try {
+        Gio.AppInfo.launch_default_for_uri(url, ctx);
+    } catch(e) {
+        let n = new AppNotifications.SimpleOutput(_("Failed to open link"));
+        let app = Gio.Application.get_default();
+        app.notificationQueue.addNotification(n);
+        debug("failed to open %s: %s".format(url, e.message));
+    }
+}
+
 function gpaste(text, title, callback) {
     let params = {
         title: title,
